#!/usr/bin/env python
# coding: utf-8

# In[129]:


import numpy as np
import scipy.optimize as spo
from matplotlib import pyplot as plt   
plt.rcParams['axes.grid'] = True      
plt.rcParams['savefig.format'] = 'png' 


# In[130]:


y = np.array([]) #Tension primaire(V)
x = np.array([])*10**(-3) #Courant primaire(A)
ux= 0.002*x + 0.002*0.2
uy= 0.002*y + 0.002*15 #incertitudes constructeurs

y_exp = np.array([])
x_exp = np.array([])*10**(-3)
ux_exp= 0.002*x_exp + 0.002*0.2
uy_exp= 0.002*y_exp + 0.002*15 


x = np.concatenate((x,x_exp))
y = np.concatenate((y,y_exp))
ux= np.concatenate((ux,ux_exp))
uy= np.concatenate((uy,uy_exp))


# In[131]:


def f(x,p):
    a,b = p
    return a*x+b

def Dx_f(x,p):
    a,b = p
    return a

def residual(p,y,x):
    return (y-f(x,p))/np.sqrt(uy**2 +(Dx_f(x,p)*ux)**2)


# In[132]:


p0 = np.array([0.1,0.1])

result = spo.leastsq(residual,p0,args=(y,x), full_output=True)
popt = result[0]
pcov = result[1]
upopt = np.sqrt(np.abs(np.diagonal(pcov)))


# In[133]:


plt.figure(figsize=(16,8))
x_mod = np.linspace(np.amin(x),np.amax(x),1000)
y_mod = f(x_mod,popt)
plt.plot(x_mod,y_mod,label='Modèle affine $y = a x + b$', color = 'blue', linestyle= '-')
plt.errorbar(x,y,xerr=ux,yerr=uy,marker='+', color = 'red', linestyle= '',label='Points pris en préparation')
plt.errorbar(x_exp,y_exp,xerr=ux_exp,yerr=uy_exp,marker='+', color = 'green', linestyle= '',label='Point(s) pris en direct')
plt.ylabel('Tension primaire(V)',fontsize=32)
plt.xlabel('Courant primaire(A)',fontsize=32)
plt.title('Loi d\'Ohm dans le primaire', fontsize = 40)
plt.xticks(fontsize=32)
plt.yticks(fontsize=32)
plt.xlim(0.9*np.amin(x), 1.01*np.amax(x))
plt.ylim(0.9*np.amin(y), 1.01*np.amax(y))
plt.legend(loc='upper left',fontsize=25)
plt.text((np.amin(x)+np.amax(x))/2.5, np.amin(y) + (np.amin(y) + np.amax(y))/10 , 'Résistance primaire = ' + str(round(popt[0],1)) + ' ± ' + str(round(upopt[0],1)) + ' $\\Omega$',fontsize=16)
plt.show()
Rp = popt[0]
uRp = upopt[0]


# In[134]:


x = np.array([])*10**(-3) #Tension secondaire(V)
y = np.array([]) # Courant secondaire(A)
ux= 0.002*x + 0.002*5
uy= 0.002*y + 0.002*15

x_exp = np.array([])*10**(-3)
y_exp = np.array([])
ux_exp= 0.002*x_exp + 0.002*0.2
uy_exp= 0.002*y_exp + 0.002*15 


x = np.concatenate((x,x_exp))
y = np.concatenate((y,y_exp))
ux= np.concatenate((ux,ux_exp))
uy= np.concatenate((uy,uy_exp))


# In[135]:


p0 = np.array([0.1,0.1])

result = spo.leastsq(residual,p0,args=(y,x), full_output=True)
popt = result[0]
pcov = result[1]
upopt = np.sqrt(np.abs(np.diagonal(pcov)))


# In[136]:


plt.figure(figsize=(16,8))
x_mod = np.linspace(np.amin(x),np.amax(x),1000)
y_mod = f(x_mod,popt)
plt.plot(x_mod,y_mod,label='Modèle affine $y = a x + b$', color = 'blue', linestyle= '-')
plt.errorbar(x,y,xerr=ux,yerr=uy,marker='+', color = 'red', linestyle= '',label='Points pris en préparation')
plt.errorbar(x_exp,y_exp,xerr=ux_exp,yerr=uy_exp,marker='+', color = 'green', linestyle= '',label='Point(s) pris en direct')
plt.ylabel('Tension secondaire(V)',fontsize=32)
plt.xlabel('Courant secondaire(A)',fontsize=32)
plt.title('Loi d\'Ohm dans le secondaire', fontsize = 40)
plt.xticks(fontsize=32)
plt.yticks(fontsize=32)
plt.xlim(0.9*np.amin(x), 1.01*np.amax(x))
plt.ylim(0.9*np.amin(y), 1.01*np.amax(y))
plt.legend(loc='upper left',fontsize=25)
plt.text((np.amin(x)+np.amax(x))/2.5, np.amin(y) + (np.amin(y) + np.amax(y))/10 , 'Résistance secondaire = ' + str(round(popt[0],2)) + ' ± ' + str(round(upopt[0],2)) + ' $\\Omega$',fontsize=16)
plt.show()
Rs = popt[0]
uRs = upopt[1]


# In[137]:


Up = np.array([]) 
Ip = np.array([]) *10**(-3)
Pp = np.array([])
Us = np.array([])
Is = np.array([]) *10**(-3)
Ps = np.array([])

print(len(Up),len(Ip),len(Pp),len(Us),len(Is),len(Ps))

uUp= 0.001 * Up + 0.001 * 600
uIp= 0.001 * Ip + 0.001 * 0.2
uPp= 0.001 * Pp + 0.001 * 120
uUs= 0.001 * Us + 0.001 * 30
uIs= 0.001 * Is + 0.001 * 5
uPs= 0.001 * Ps + 0.001 * 60

x = Pp
y = Ps/Pp
ux= uPp
uy= y * np.sqrt((uPp/Pp)**2+(uPs/Ps)**2)

#Ps_exp = np.array([])
#Pe_exp = np.array([])
#uPs_exp= 0.002*x_exp + 0.002*0.2
#uPe_exp= 0.002*y_exp + 0.002*15 

#x_exp = np.array([])
#y_exp = np.array([])
#ux_exp= 
#uy_exp= 

#x = np.concatenate((x,x_exp))
#y = np.concatenate((y,y_exp))
#ux= np.concatenate((ux,ux_exp))
#uy= np.concatenate((uy,uy_exp))

#p0 = np.array([0.1,0.1])

#result = spo.leastsq(residual,p0,args=(y,x), full_output=True)
#popt = result[0]
#pcov = result[1]
#upopt = np.sqrt(np.abs(np.diagonal(pcov)))

plt.figure(figsize=(16,8))
#x_mod = np.linspace(np.amin(x),np.amax(x),1000)
#y_mod = f(x_mod,popt)
#plt.plot(x_mod,y_mod,label='Modèle affine $y = a x + b$', color = 'blue', linestyle= '-')
plt.errorbar(x,y,xerr=ux,yerr=uy,marker='+', color = 'red', linestyle= '',label='Points pris en préparation')
#plt.errorbar(x_exp,y_exp,xerr=ux_exp,yerr=uy_exp,marker='+', color = 'green', linestyle= '',label='Point(s) pris en direct')
plt.xlabel('Puissance primaire (W)',fontsize=32)
plt.ylabel('Rendement $\\frac{P_{secondaire}}{P_{primaire}}$ (W)',fontsize=32)
plt.title('Courbe de rendement', fontsize = 40)
plt.xticks(fontsize=32)
plt.yticks(fontsize=32)
#plt.xlim(0.9*np.amin(x), 1.05*np.amax(x))
#plt.ylim(0.9*np.amin(y), 1.05*np.amax(y))

plt.legend(loc='upper left',fontsize=25)
#plt.text((np.amin(x)+np.amax(x))/2.5, np.amin(y) + (np.amin(y) + np.amax(y))/10 , 'Pente a = ' + str(round(popt[0],10)) + ' ± ' + str(round(upopt[0],10)) + ' unité',fontsize=16)
#plt.text((np.amin(x)+np.amax(x))/2.5, np.amin(y) + (np.amin(y) + np.amax(y))/20, 'Ordonnée à l\'origine = ' + str(round(popt[1],10)) + ' ± ' + str(round(upopt[1],10)) + ' unité',fontsize=16)
plt.show()


# In[147]:


Up = 
uUp = 
Ip =  *10**(-3)
uIp =  *10**(-3)
Pp = 
uPp = 

P_fer = 
uP_fer = 
print(P_fer,uP_fer)


# In[152]:


Up = np.array([]) 
Ip = np.array([]) *10**(-3)
Pp = np.array([])
Us = np.array([])
Is = np.array([]) *10**(-3)
Ps = np.array([])

uUp= 0.001 * Up + 0.001 * 600
uIp= 0.001 * Ip + 0.001 * 0.2
#uPp= 0.001 * Pp + 0.001 * 120
uPs= np.full(len(x), 0.5)
uUs= 0.001 * Us + 0.001 * 30
uIs= 0.001 * Is + 0.001 * 5
#uPs= 0.001 * Ps + 0.001 * 60
uPs= np.full(len(x), 0.5)

x = Pp
ux= uPp
y1 = Rp * Ip**2
uy1 = y1 * np.sqrt((uRp/Rp)**2 + (2*uIp/Ip)**2)
y2 = Rs * Is**2
uy2 = y2 * np.sqrt((uRs/Rs)**2 + (2*uIs/Is)**2)
y3 = y1 + y2
uy3 = np.sqrt(uy1**2 + uy2**2)
y4 = np.full(len(x),P_fer)
uy4 = np.full(len(x),uP_fer)
y5 = y3 + y4
uy5 = np.sqrt(uy3**2 + uy4**2)
y6 = Pp - Ps
uy6 = np.sqrt(uPp**2 + uPs **2)




plt.figure(figsize=(16,8))
plt.errorbar(x,y1,xerr=ux,yerr=uy1,marker='+', color = 'red', linestyle= '',label='Pertes Joule dans le primaire')
plt.errorbar(x,y2,xerr=ux,yerr=uy2,marker='+', color = 'green', linestyle= '',label='Pertes Joule dans le secondaire')
plt.errorbar(x,y3,xerr=ux,yerr=uy3,marker='+', color = 'blue', linestyle= '',label='Pertes Joule totales')
plt.errorbar(x,y4,xerr=ux,yerr=uy4,marker='+', color = 'cyan', linestyle= '',label='Pertes fer')
plt.errorbar(x,y5,xerr=ux,yerr=uy5,marker='+', color = 'magenta', linestyle= '',label='Sommes Pertes fer et Joule')
plt.errorbar(x,y6,xerr=ux,yerr=uy6,marker='+', color = 'black', linestyle= '',label='Pertes totales mesurées')
plt.xlabel('Puissance primaire (W)',fontsize=32)
plt.ylabel('Puissance des pertes (W)',fontsize=32)
plt.title('Pertes dans la transformation', fontsize = 40)
plt.xticks(fontsize=32)
plt.yticks(fontsize=32)
plt.ylim(-0.2,15)
plt.legend(loc='upper left',fontsize=25)
plt.show()


# In[ ]:




